#include <QImage>
#include <iostream>

int main(int argc, char *argv[])
{
    const quint32 width = 480U;
    const quint32 height = 360U;

    static quint8 framebufferRGBA8888[width * height * 4U];
    static quint8 framebufferARGB32[width * height * 4U];

    for (auto pixelIndex = 0U; pixelIndex < (width * height); ++pixelIndex) {
        framebufferRGBA8888[pixelIndex * 4U + 0U] = 0x00U;  // R
        framebufferRGBA8888[pixelIndex * 4U + 1U] = 0xffU;  // G
        framebufferRGBA8888[pixelIndex * 4U + 2U] = 0x00U;  // B
        framebufferRGBA8888[pixelIndex * 4U + 3U] = 0xffU;  // A

        framebufferARGB32[pixelIndex * 4U + 3U] = 0xffU;  // A
        framebufferARGB32[pixelIndex * 4U + 0U] = 0x00U;  // R
        framebufferARGB32[pixelIndex * 4U + 1U] = 0xffU;  // G
        framebufferARGB32[pixelIndex * 4U + 2U] = 0x00U;  // B

    }

    QImage imageRGBA8888(framebufferRGBA8888, width, height, width * 4U, QImage::Format_RGBA8888);
    QImage imageARGB32(framebufferARGB32, width, height, width * 4U, QImage::Format_ARGB32);
    imageRGBA8888.save("green_test_output_RGBA8888.png");   // save rendered image for later inspection
    imageARGB32.save("green_test_output_ARGB32.png");

    QImage referenceRGBA8888;
    QImage referenceARGB32;
    referenceRGBA8888.load("green_test_output_RGBA8888.png");
    referenceARGB32.load("green_test_output_ARGB32.png");

    if (imageRGBA8888 == referenceRGBA8888) {
        std::cout << "The RGBA8888 Images are the same." << std::endl;
    } else {
        std::cout << "The RGBA8888 Images differ from each other." << std::endl;
    }

    if (imageARGB32 == referenceARGB32) {
        std::cout << "The ARGB32 Images are the same." << std::endl;
    } else {
        std::cout << "The ARGB32 Images differ from each other." << std::endl;
    }

    return 0;
}
